BaseCost — skchange

Skip to main content
`Ctrl`+`K`

# BaseCost

BaseCost(param=None)

  Base class template for cost functions.

  This is a common base class for cost functions. It is used to evaluate a cost function on a set of intervals.

  Parameters:
    paramNone, optional (default=None)

      If None, the cost for an optimal parameter is evaluated. If not None, the cost is evaluated for a fixed parameter. The parameter type is specific to each concrete cost.